;; Generated package description from ahungry-theme.el  -*- no-byte-compile: t -*-
(define-package "ahungry-theme" "1.10.0.0.20211231.115425" "Ahungry color theme for Emacs.  Make sure to (load-theme 'ahungry)." '((emacs "24")) :commit "7d18c85c014671573628686012f3952fcd72c97b" :authors '(("Matthew Carter" . "m@ahungry.com")) :maintainer '("Matthew Carter" . "m@ahungry.com") :keywords '("ahungry" "palette" "color" "theme" "emacs" "color-theme" "deftheme") :url "https://github.com/ahungry/color-theme-ahungry")
